aboutsummaryrefslogtreecommitdiffstats
path: root/main_statusbar.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2010-11-27 23:06:14 +0000
committerGuy Harris <guy@alum.mit.edu>2010-11-27 23:06:14 +0000
commit002a1b75fa2b388ddcc1c5dd9487ebf6ec54ed39 (patch)
treef88b3a83e60b129e5e55f6c9d8a319313279a2d7 /main_statusbar.h
parenta4cc25f84d04835a8283176ba4a058b5ac2966e2 (diff)
Make some other statusbar routines take a format string and format args,
and get rid of an unnecessary string pointer. Make the argument to welcome_header_push_msg() a const pointer. svn path=/trunk/; revision=35042
Diffstat (limited to 'main_statusbar.h')
-rw-r--r--main_statusbar.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/main_statusbar.h b/main_statusbar.h
index 6bf4d7ba7e..92ecd27c44 100644
--- a/main_statusbar.h
+++ b/main_statusbar.h
@@ -29,21 +29,23 @@ void profile_bar_update(void);
void packets_bar_update(void);
void status_expert_update(void);
-/** Push a message referring to the currently-selected field onto the statusbar.
+/** Push a formatted message referring to the currently-selected field
+ * onto the statusbar.
*
* @param msg The message
*/
-void statusbar_push_field_msg(const gchar *msg);
+void statusbar_push_field_msg(const gchar *msg_format, ...);
/** Pop a message referring to the currently-selected field off the statusbar.
*/
void statusbar_pop_field_msg(void);
-/** Push a message referring to the current filter onto the statusbar.
+/** Push a formatted message referring to the current filter onto the
+ * statusbar.
*
* @param msg The message
*/
-void statusbar_push_filter_msg(const gchar *msg);
+void statusbar_push_filter_msg(const gchar *msg_format, ...);
/** Pop a message referring to the current filter off the statusbar.
*/
@@ -29,21 +29,23 @@ void profile_bar_update(void);
*
- * @param msg The message
+ * @param msg_format The format string for the message
*/
@@ -29,21 +29,23 @@ void profile_bar_update(void);
*
- * @param msg The message
+ * @param msg_format The format string for the message
*/